@@ -20,7 +20,7 @@ class ESDocument(BaseModel):
     author: Optional[str] = ""
     repo: Optional[str] = ""
     readme: Optional[str] = ""
-    spatial: Optional[str] = ""
+    spatial: Optional[Union[str, List[str]]] = ""
     accessRights: Optional[common_fields.AccessRights] = common_fields.AccessRights.INTERNAL.value
     pii: Optional[common_fields.Pii] = common_fields.Pii.FALSE.value
     keyword: Optional[Sequence] = []
@@ -33,3 +33,5 @@ class ESDocument(BaseModel):
     rights: Optional[str] = f"Copyright {date.today().year}, NAV"
     content: Optional[dict] = {}
     url: Optional[str] = ""
+    master: Optional[str] = ""
+
